@@ -3,4 +3,4 @@
 dir=`dirname $0`
 
 # Use common Linux directory to avoid loading su much data
-$dir/set_linux_dir.sh ..\\/linux-2.6-git
+$dir/set_linux_dir.sh ..\\/linux-src
